%bcond_with reconf

%define major 12
%define minor 2
%define postgres_prefix %{_libdir}/%{name}

Name: postgresql%{major}
Summary: PostgreSQL client programs
Version: %{major}.%{minor}
Release: 2
License: PostgreSQL
URL: http://www.postgresql.org/

Source0: https://ftp.postgresql.org/pub/source/v%{version}/postgresql-%{version}.tar.gz

Patch0: postgresql12-shlib.patch
Patch1: postgresql12-workaround-bad-locale-segfault.patch

# Build Requirements https://www.postgresql.org/docs/12/install-requirements.html
BuildRequires: libgettextpo-devel
BuildRequires: gettext-runtime
BuildRequires: gettext-tools
BuildRequires: libintl-devel
BuildRequires: readline-devel
BuildRequires: zlib-devel
BuildRequires: openssl-devel >= 1.1.1
BuildRequires: libgettextpo1
BuildRequires: libgettextpo-devel
BuildRequires: libxml2-devel
BuildRequires: libxslt-devel

Requires: %{name}-libpq = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
PostgreSQL is an advanced Object-Relational database management system
(DBMS) that supports almost all SQL constructs (including
transactions, sub-selects and user-defined types and functions). The
postgresql package includes the client programs and libraries that
you'll need to access a PostgreSQL DBMS server.  These PostgreSQL
client programs are programs that directly manipulate the internal
structure of PostgreSQL databases on a PostgreSQL server. These client
programs can be located on the same machine with the PostgreSQL
server, or may be on a remote machine which accesses a PostgreSQL
server over a network connection. This package contains the command-line
utilities for managing PostgreSQL databases on a PostgreSQL server.

%package libpq
Provides: lib:%{_libdir}/libpq.so.5(shr_64.o)(ppc64)
Summary: Shared library for any PostgreSQL client program or interface.
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description libpq
The libpq package provides the essential shared library for any PostgreSQL
client program or interface. You will need to install this package to use any
other PostgreSQL package or any clients that need to connect to a PostgreSQL
server.

%package libpgtypes
Provides: lib:%{_libdir}/libpgtypes.so.3(shr_64.o)(ppc64)
Summary: Shared library that maps PostgreSQL database types to C equivalents
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description libpgtypes
The pgtypes library maps PostgreSQL database types to C equivalents that can be
used in C programs. It also offers functions to do basic calculations with those
types within C, i.e., without the help of the PostgreSQL server.

%package libecpg
Requires: %{name}-libpgtypes = %{version}-%{release}
Requires: %{name}-libpq = %{version}-%{release}
Summary: Shared library for Embedded SQL in C

%description libecpg
An embedded SQL program consists of code written in an ordinary programming
language, in this case C, mixed with SQL commands in specially marked sections.
To build the program, the source code (*.pgc) is first passed through the
embedded SQL preprocessor, which converts it to an ordinary C program (*.c), and
afterwards it can be processed by a C compiler.

%package server
Summary: The programs needed to create and run a PostgreSQL server
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libpq = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description server
The postgresql-server package includes the programs needed to create
and run a PostgreSQL server, which will in turn allow you to create
and maintain PostgreSQL databases. You should install
postgresql-server if you want to create and maintain your own
PostgreSQL databases and/or your own PostgreSQL server.

%package docs
Summary: Extra documentation for PostgreSQL
Requires: %{name} = %{version}-%{release}

%description docs
The postgresql-docs package includes the main documentation in HTML format.

%package contrib
Summary: Contributed modules distributed with PostgreSQL
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-libpq = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description contrib
The postgresql-contrib package contains contributed packages that are
included in the PostgreSQL distribution.

%package devel
Summary: PostgreSQL development header files and libraries
Requires: %{name}-libpq = %{version}-%{release}
Requires: %{name}-libpgtypes = %{version}-%{release}
Requires: %{name}-libecpg = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description devel
The postgresql-devel package contains the header files and libraries
needed to compile C or C++ applications which will directly interact
with a PostgreSQL database management server and the ecpg Embedded C
Postgres preprocessor.

%prep
%setup -q -n postgresql-%{version}
%patch0 -p1
%patch1 -p1

%build

%define _host powerpc-ibm-aix6

# configure options: https://www.postgresql.org/docs/12/install-procedure.html
# %configure was not used because we use a custom prefix and exec prefix
./configure --host=%{_host} --build=%{_host} \
    ac_cv_func_shm_open=no \
    ac_cv_func_posix_fadvise=no \
    ac_cv_func_getpeereid=no \
    %{?with_reconf:--with-aix-soname=svr4} \
    --prefix=%{postgres_prefix} \
    --exec-prefix=%{postgres_prefix} \
    --enable-thread-safety \
    --with-openssl \
    --with-libxml \
    --with-libxslt \
    --enable-nls \
    #end

# build everything
%make_build world

# Test the newly built server before you install it
%check
make check

%install
make install-world DESTDIR=%{buildroot}

# dont ship .a(so.x) files we now have svr4 style equivalents
rm %{buildroot}%{postgres_prefix}/lib/libecpg.a
rm %{buildroot}%{postgres_prefix}/lib/libecpg_compat.a
rm %{buildroot}%{postgres_prefix}/lib/libpgtypes.a
rm %{buildroot}%{postgres_prefix}/lib/libpq.a

%post libpq
%{_bindir}/update-alternatives --install %{_libdir}/libpq.so.5 libpq %{postgres_prefix}/lib/libpq.so.5 %{major}

%postun libpq
%{_bindir}/update-alternatives --remove libpq %{postgres_prefix}/lib/libpq.so.5

%post libpgtypes
%{_bindir}/update-alternatives --install %{_libdir}/libpgtypes.so.3 libpgtypes %{postgres_prefix}/lib/libpgtypes.so.3 %{major}

%postun libpgtypes
%{_bindir}/update-alternatives --remove libpgtypes %{postgres_prefix}/lib/libpgtypes.so.3

%post
%{_bindir}/update-alternatives --install %{_bindir}/psql postgresql-client %{postgres_prefix}/bin/psql %{major} \
  --slave %{_bindir}/clusterdb clusterdb %{postgres_prefix}/bin/clusterdb \
  --slave %{_bindir}/createdb createdb %{postgres_prefix}/bin/createdb \
  --slave %{_bindir}/createuser createuser %{postgres_prefix}/bin/createuser \
  --slave %{_bindir}/dropdb dropdb %{postgres_prefix}/bin/dropdb \
  --slave %{_bindir}/dropuser dropuser %{postgres_prefix}/bin/dropuser \
  --slave %{_bindir}/pg_dump pg_dump %{postgres_prefix}/bin/pg_dump \
  --slave %{_bindir}/pg_dumpall pg_dumpall %{postgres_prefix}/bin/pg_dumpall \
  --slave %{_bindir}/pg_isready pg_isready %{postgres_prefix}/bin/pg_isready \
  --slave %{_bindir}/pg_restore pg_restore %{postgres_prefix}/bin/pg_restore \
  --slave %{_bindir}/pg_upgrade pg_upgrade %{postgres_prefix}/bin/pg_upgrade \
  --slave %{_bindir}/reindexdb reindexdb %{postgres_prefix}/bin/reindexdb \
  --slave %{_bindir}/vacuumdb vacuumdb %{postgres_prefix}/bin/vacuumdb

%postun
%{_bindir}/update-alternatives --remove postgresql-client %{postgres_prefix}/bin/psql

%post server
%{_bindir}/update-alternatives --install %{_bindir}/postgres postgresql-server %{postgres_prefix}/bin/postgres %{major} \
    --slave %{_bindir}/initdb initdb %{postgres_prefix}/bin/initdb \
    --slave %{_bindir}/pg_basebackup pg_basebackup %{postgres_prefix}/bin/pg_basebackup \
    --slave %{_bindir}/pg_checksums pg_checksums %{postgres_prefix}/bin/pg_checksums \
    --slave %{_bindir}/pg_controldata pg_controldata %{postgres_prefix}/bin/pg_controldata \
    --slave %{_bindir}/pg_ctl pg_ctl %{postgres_prefix}/bin/pg_ctl \
    --slave %{_bindir}/pg_receivewal pg_receivewal %{postgres_prefix}/bin/pg_receivewal \
    --slave %{_bindir}/pg_recvlogical pg_recvlogical %{postgres_prefix}/bin/pg_recvlogical \
    --slave %{_bindir}/pg_resetwal pg_resetwal %{postgres_prefix}/bin/pg_resetwal \
    --slave %{_bindir}/postmaster postmaster %{postgres_prefix}/bin/postmaster

%postun server
%{_bindir}/update-alternatives --remove postgresql-server %{postgres_prefix}/bin/postgres

%post devel
%{_bindir}/update-alternatives --install %{_bindir}/pg_config postgresql-devel %{postgres_prefix}/bin/pg_config %{major} \
    --slave %{_bindir}/ecpg ecpg %{postgres_prefix}/bin/ecpg

%postun devel
%{_bindir}/update-alternatives --remove postgresql-devel %{postgres_prefix}/bin/pg_config

%post contrib
%{_bindir}/update-alternatives --install %{_bindir}/pgbench postgresql-contrib %{postgres_prefix}/bin/pgbench %{major} \
    --slave %{_bindir}/oid2name oid2name %{postgres_prefix}/bin/oid2name \
    --slave %{_bindir}/pg_archivecleanup pg_archivecleanup %{postgres_prefix}/bin/pg_archivecleanup \
    --slave %{_bindir}/pg_standby pg_standby %{postgres_prefix}/bin/pg_standby \
    --slave %{_bindir}/pg_test_fsync pg_test_fsync %{postgres_prefix}/bin/pg_test_fsync \
    --slave %{_bindir}/pg_test_timing pg_test_timing %{postgres_prefix}/bin/pg_test_timing \
    --slave %{_bindir}/pg_waldump pg_waldump %{postgres_prefix}/bin/pg_waldump \
    --slave %{_bindir}/vacuumlo vacuumlo %{postgres_prefix}/bin/vacuumlo

%postun contrib
%{_bindir}/update-alternatives --remove postgresql-contrib %{postgres_prefix}/bin/pgbench

%files libpq
%defattr(-, qsys, *none)
%{postgres_prefix}/lib/libpq.so.5

%files libpgtypes
%defattr(-, qsys, *none)
%{postgres_prefix}/lib/libpgtypes.so.3

%files libecpg
%defattr(-, qsys, *none)
%{postgres_prefix}/lib/libecpg.so.6
%{postgres_prefix}/lib/libecpg_compat.so.3

%files
%defattr(-, qsys, *none)
%{postgres_prefix}/bin/clusterdb
%{postgres_prefix}/bin/createdb
%{postgres_prefix}/bin/createuser
%{postgres_prefix}/bin/dropdb
%{postgres_prefix}/bin/dropuser
%{postgres_prefix}/bin/pg_dump
%{postgres_prefix}/bin/pg_dumpall
%{postgres_prefix}/bin/pg_isready
%{postgres_prefix}/bin/pg_restore
%{postgres_prefix}/bin/pg_upgrade
%{postgres_prefix}/bin/psql
%{postgres_prefix}/bin/reindexdb
%{postgres_prefix}/bin/vacuumdb

%{postgres_prefix}/share/man/man1/clusterdb.1
%{postgres_prefix}/share/man/man1/createdb.1
%{postgres_prefix}/share/man/man1/createuser.1
%{postgres_prefix}/share/man/man1/dropdb.1
%{postgres_prefix}/share/man/man1/dropuser.1
%{postgres_prefix}/share/man/man1/pg_dump.1
%{postgres_prefix}/share/man/man1/pg_dumpall.1
%{postgres_prefix}/share/man/man1/pg_isready.1
%{postgres_prefix}/share/man/man1/pg_restore.1
%{postgres_prefix}/share/man/man1/pg_upgrade.1
%{postgres_prefix}/share/man/man1/psql.1
%{postgres_prefix}/share/man/man1/reindexdb.1
%{postgres_prefix}/share/man/man1/vacuumdb.1
%{postgres_prefix}/share/man/man7/*

%files server
%defattr(-, qsys, *none)
%{postgres_prefix}/bin/initdb
%{postgres_prefix}/bin/pg_basebackup
%{postgres_prefix}/bin/pg_checksums
%{postgres_prefix}/bin/pg_controldata
%{postgres_prefix}/bin/pg_ctl
%{postgres_prefix}/bin/pg_receivewal
%{postgres_prefix}/bin/pg_recvlogical
%{postgres_prefix}/bin/pg_resetwal
%{postgres_prefix}/bin/pg_rewind
%{postgres_prefix}/bin/postgres
%{postgres_prefix}/bin/postmaster

%{postgres_prefix}/lib/pgoutput.so
%{postgres_prefix}/lib/postgres.imp
%{postgres_prefix}/lib/dict_snowball.so
%{postgres_prefix}/lib/plpgsql.so
%{postgres_prefix}/lib/libpqwalreceiver.so
%{postgres_prefix}/lib/pg_prewarm.so
%{postgres_prefix}/lib/*_and_*.so
%{postgres_prefix}/lib/euc2004_sjis2004.so

%dir %{postgres_prefix}/share
%{postgres_prefix}/share/pg_hba.conf.sample
%{postgres_prefix}/share/pg_ident.conf.sample
%{postgres_prefix}/share/pg_service.conf.sample
%{postgres_prefix}/share/postgresql.conf.sample
%{postgres_prefix}/share/psqlrc.sample

%dir %{postgres_prefix}/share/extension
%{postgres_prefix}/share/extension/plpgsql*
%{postgres_prefix}/share/information_schema.sql
%{postgres_prefix}/share/postgres.bki
%{postgres_prefix}/share/postgres.description
%{postgres_prefix}/share/postgres.shdescription
%{postgres_prefix}/share/snowball_create.sql
%{postgres_prefix}/share/sql_features.txt
%{postgres_prefix}/share/system_views.sql
%{postgres_prefix}/share/timezone/
%{postgres_prefix}/share/timezonesets/
%{postgres_prefix}/share/tsearch_data/
%{postgres_prefix}/share/errcodes.txt

%{postgres_prefix}/share/man/man1/initdb.1
%{postgres_prefix}/share/man/man1/pg_basebackup.1
%{postgres_prefix}/share/man/man1/pg_checksums.1
%{postgres_prefix}/share/man/man1/pg_controldata.1
%{postgres_prefix}/share/man/man1/pg_ctl.1
%{postgres_prefix}/share/man/man1/pg_receivewal.1
%{postgres_prefix}/share/man/man1/pg_resetwal.1
%{postgres_prefix}/share/man/man1/pg_rewind.1
%{postgres_prefix}/share/man/man1/postgres.1
%{postgres_prefix}/share/man/man1/postmaster.1

%files devel
%defattr(-, qsys, *none)
%{postgres_prefix}/bin/ecpg
%{postgres_prefix}/bin/pg_config

%{postgres_prefix}/include/

%{postgres_prefix}/lib/pgxs/
%{postgres_prefix}/lib/pkgconfig/*.pc
%{postgres_prefix}/lib/libecpg.so
%{postgres_prefix}/lib/libecpg_compat.so
%{postgres_prefix}/lib/libpgtypes.so
%{postgres_prefix}/lib/libpq.so
# Static libraries
%{postgres_prefix}/lib/libpgcommon.a
%{postgres_prefix}/lib/libpgfeutils.a
%{postgres_prefix}/lib/libpgport.a
%{postgres_prefix}/lib/libpgcommon_shlib.a
%{postgres_prefix}/lib/libpgport_shlib.a

%{postgres_prefix}/share/man/man1/ecpg.1
%{postgres_prefix}/share/man/man1/pg_config.1
%{postgres_prefix}/share/man/man3/SPI_*

%{postgres_prefix}/share/locale/*

%files docs
%defattr(-, qsys, *none)
%{postgres_prefix}/share/doc/html/*

%files contrib
%defattr(-, qsys, *none)
%{postgres_prefix}/bin/oid2name
%{postgres_prefix}/bin/pg_archivecleanup
%{postgres_prefix}/bin/pg_standby
%{postgres_prefix}/bin/pg_test_fsync
%{postgres_prefix}/bin/pg_test_timing
%{postgres_prefix}/bin/pg_waldump
%{postgres_prefix}/bin/pgbench
%{postgres_prefix}/bin/vacuumlo

%{postgres_prefix}/share/extension/adminpack*
%{postgres_prefix}/share/extension/amcheck*
%{postgres_prefix}/share/extension/autoinc*
%{postgres_prefix}/share/extension/bloom*
%{postgres_prefix}/share/extension/btree_gin*
%{postgres_prefix}/share/extension/btree_gist*
%{postgres_prefix}/share/extension/citext*
%{postgres_prefix}/share/extension/cube*
%{postgres_prefix}/share/extension/dblink*
%{postgres_prefix}/share/extension/dict_int*
%{postgres_prefix}/share/extension/dict_xsyn*
%{postgres_prefix}/share/extension/earthdistance*
%{postgres_prefix}/share/extension/file_fdw*
%{postgres_prefix}/share/extension/fuzzystrmatch*
%{postgres_prefix}/share/extension/hstore*
%{postgres_prefix}/share/extension/insert_username*
%{postgres_prefix}/share/extension/intagg*
%{postgres_prefix}/share/extension/intarray*
%{postgres_prefix}/share/extension/isn*
%{postgres_prefix}/share/extension/lo*
%{postgres_prefix}/share/extension/ltree*
%{postgres_prefix}/share/extension/moddatetime*
%{postgres_prefix}/share/extension/pageinspect*
%{postgres_prefix}/share/extension/pg_buffercache*
%{postgres_prefix}/share/extension/pg_freespacemap*
%{postgres_prefix}/share/extension/pg_prewarm*
%{postgres_prefix}/share/extension/pg_stat_statements*
%{postgres_prefix}/share/extension/pg_trgm*
%{postgres_prefix}/share/extension/pg_visibility*
%{postgres_prefix}/share/extension/pgcrypto*
%{postgres_prefix}/share/extension/pgrowlocks*
%{postgres_prefix}/share/extension/pgstattuple*
%{postgres_prefix}/share/extension/postgres_fdw*
%{postgres_prefix}/share/extension/refint*
%{postgres_prefix}/share/extension/seg*
%{postgres_prefix}/share/extension/tablefunc*
%{postgres_prefix}/share/extension/tcn*
%{postgres_prefix}/share/extension/tsm_system_rows*
%{postgres_prefix}/share/extension/tsm_system_time*
%{postgres_prefix}/share/extension/unaccent*
%{postgres_prefix}/share/extension/xml2*
%{postgres_prefix}/share/extension/sslinfo*

%{postgres_prefix}/share/doc/extension/autoinc.example
%{postgres_prefix}/share/doc/extension/insert_username.example
%{postgres_prefix}/share/doc/extension/moddatetime.example
%{postgres_prefix}/share/doc/extension/refint.example

%{postgres_prefix}/lib/_int.so
%{postgres_prefix}/lib/adminpack.so
%{postgres_prefix}/lib/amcheck.so
%{postgres_prefix}/lib/auth_delay.so
%{postgres_prefix}/lib/auto_explain.so
%{postgres_prefix}/lib/autoinc.so
%{postgres_prefix}/lib/bloom.so
%{postgres_prefix}/lib/btree_gin.so
%{postgres_prefix}/lib/btree_gist.so
%{postgres_prefix}/lib/citext.so
%{postgres_prefix}/lib/cube.so
%{postgres_prefix}/lib/dblink.so
%{postgres_prefix}/lib/dict_int.so
%{postgres_prefix}/lib/dict_xsyn.so
%{postgres_prefix}/lib/earthdistance.so
%{postgres_prefix}/lib/file_fdw.so
%{postgres_prefix}/lib/fuzzystrmatch.so
%{postgres_prefix}/lib/hstore.so
%{postgres_prefix}/lib/insert_username.so
%{postgres_prefix}/lib/isn.so
%{postgres_prefix}/lib/lo.so
%{postgres_prefix}/lib/ltree.so
%{postgres_prefix}/lib/moddatetime.so
%{postgres_prefix}/lib/pageinspect.so
%{postgres_prefix}/lib/passwordcheck.so
%{postgres_prefix}/lib/pg_buffercache.so
%{postgres_prefix}/lib/pg_freespacemap.so
%{postgres_prefix}/lib/pg_stat_statements.so
%{postgres_prefix}/lib/pg_trgm.so
%{postgres_prefix}/lib/pg_visibility.so
%{postgres_prefix}/lib/pgcrypto.so
%{postgres_prefix}/lib/pgrowlocks.so
%{postgres_prefix}/lib/pgstattuple.so
%{postgres_prefix}/lib/postgres_fdw.so
%{postgres_prefix}/lib/refint.so
%{postgres_prefix}/lib/seg.so
%{postgres_prefix}/lib/tablefunc.so
%{postgres_prefix}/lib/tcn.so
%{postgres_prefix}/lib/test_decoding.so
%{postgres_prefix}/lib/tsm_system_rows.so
%{postgres_prefix}/lib/tsm_system_time.so
%{postgres_prefix}/lib/unaccent.so
%{postgres_prefix}/lib/pgxml.so
%{postgres_prefix}/lib/sslinfo.so

%{postgres_prefix}/share/man/man1/oid2name.1
%{postgres_prefix}/share/man/man1/pg_archivecleanup.1
%{postgres_prefix}/share/man/man1/pg_recvlogical.1
%{postgres_prefix}/share/man/man1/pg_standby.1
%{postgres_prefix}/share/man/man1/pg_test_fsync.1
%{postgres_prefix}/share/man/man1/pg_test_timing.1
%{postgres_prefix}/share/man/man1/pg_waldump.1
%{postgres_prefix}/share/man/man1/pgbench.1
%{postgres_prefix}/share/man/man1/vacuumlo.1
%{postgres_prefix}/share/man/man3/dblink*

%changelog
* Fri May 1 2020 - Abdirahim Musse <abdirahim.musse@ibm.com>
- Fix locale issue causing initdb to fail

* Wed Feb 19 2020 - Abdirahim Musse <abdirahim.musse@ibm.com>
- Initial spec
